@@ -23,7 +23,7 @@ async def _get_client(ls: int):
 
 
 def get_client(ls: int = 0):
-    client = asyncio.run(_get_client(ls))
+    client = asyncio.get_event_loop().run_until_complete(_get_client(ls))
     return client
 
 
